==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property exacts Values sent must match the specified values exactly.
 */
public data class VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs(
    public val exacts: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs =
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.builder()
            .exacts(exacts.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgsBuilder internal
constructor() {
    private var exacts: Output<List<String>>? = null

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("prisqyeeuekhldbp")
    public suspend fun exacts(`value`: Output<List<String>>) {
        this.exacts = value
    }

    @JvmName("cwvtiggoiivusjwo")
    public suspend fun exacts(vararg values: Output<String>) {
        this.exacts = Output.all(values.asList())
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("yehrnuvuxvhvitha")
    public suspend fun exacts(values: List<Output<String>>) {
        this.exacts = Output.all(values)
    }

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("akjacjquiucmddjw")
    public suspend fun exacts(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("sytpgrsvkxbyfxsx")
    public suspend fun exacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs =
        VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs(
            exacts = exacts ?: throw PulumiNullFieldException("exacts"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property exacts Values sent must match the specified values exactly.
 */
public data class VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs(
    public val exacts: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs =
        com.pulumi.aws.appmesh.inputs.VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs.builder()
            .exacts(exacts.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs].
 */
@PulumiTagMarker
public class VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgsBuilder internal constructor() {
    private var exacts: Output<List<String>>? = null

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("ckuqfhegsghtcbdb")
    public suspend fun exacts(`value`: Output<List<String>>) {
        this.exacts = value
    }

    @JvmName("mtlaurymheevqycb")
    public suspend fun exacts(vararg values: Output<String>) {
        this.exacts = Output.all(values.asList())
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("ukskycywjgsmffcy")
    public suspend fun exacts(values: List<Output<String>>) {
        this.exacts = Output.all(values)
    }

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("ydpkysthhjwsxonn")
    public suspend fun exacts(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("ijedotglaybhiqnb")
    public suspend fun exacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    internal fun build(): VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs =
        VirtualNodeSpecListenerTlsValidationSubjectAlternativeNamesMatchArgs(
            exacts = exacts ?: throw PulumiNullFieldException("exacts"),
        )
}
